Index: src/wp-admin/css/common.css
===================================================================
--- src/wp-admin/css/common.css	(revision 33083)
+++ src/wp-admin/css/common.css	(working copy)
@@ -583,9 +583,10 @@
 
 .wrap h1,
 .wrap h2 {
+	display: inline-block;
 	font-size: 23px;
 	font-weight: 400;
-	padding: 9px 15px 4px 0;
+	padding: 9px 7px 4px 0;
 	line-height: 29px;
 }
 
@@ -592,7 +593,7 @@
 .subtitle {
 	color: #777;
 	font-size: 14px;
-	padding-left: 25px;
+	padding-left: 20px;
 }
 
 .wrap .add-new-h2, /* deprecated */
@@ -599,12 +600,13 @@
 .wrap .add-new-h2:active, /* deprecated */
 .wrap .page-title-action,
 .wrap .page-title-action:active {
-	margin-left: 4px;
-	padding: 4px 8px;
+	display: inline-block;
 	position: relative;
 	top: -3px;
+	border: none;
+	margin-bottom: 6px;
+	padding: 4px 8px;
 	text-decoration: none;
-	border: none;
 	-webkit-border-radius: 2px;
 	border-radius: 2px;
 	background: #e0e0e0;
@@ -620,6 +622,7 @@
 }
 
 .wrap h1.long-header {
+	display: block; /* post revisions screen */
 	padding-right: 0;
 }
 
@@ -990,8 +993,7 @@
 .title-count {
 	display: inline;
 	top: -3px;
-	margin-left: 5px;
-	margin-right: 20px;
+	margin-right: 25px;
 }
 
 .filter-items {
Index: src/wp-admin/css/themes.css
===================================================================
--- src/wp-admin/css/themes.css	(revision 33083)
+++ src/wp-admin/css/themes.css	(working copy)
@@ -13,7 +13,6 @@
 }
 
 .themes-php .wrap h1 {
-	float: left;
 	margin-bottom: 15px;
 }
 
Index: src/wp-admin/edit-comments.php
===================================================================
--- src/wp-admin/edit-comments.php	(revision 33083)
+++ src/wp-admin/edit-comments.php	(working copy)
@@ -140,22 +140,25 @@
 ?>
 
 <div class="wrap">
+<div class="header">
 <h1><?php
-if ( $post_id )
-	echo sprintf( __( 'Comments on &#8220;%s&#8221;' ),
+if ( $post_id ) {
+	printf( __( 'Comments on &#8220;%s&#8221;' ),
 		sprintf( '<a href="%s">%s</a>',
 			get_edit_post_link( $post_id ),
 			wp_html_excerpt( _draft_or_post_title( $post_id ), 50, '&hellip;' )
 		)
 	);
-else
+} else {
 	_e( 'Comments' );
-
-if ( isset($_REQUEST['s']) && $_REQUEST['s'] )
-	echo '<span class="subtitle">' . sprintf( __( 'Search results for &#8220;%s&#8221;' ), wp_html_excerpt( esc_html( wp_unslash( $_REQUEST['s'] ) ), 50, '&hellip;' ) ) . '</span>'; ?>
-</h1>
-
+} ?></h1>
 <?php
+if ( isset( $_REQUEST['s'] ) && $_REQUEST['s'] ) {
+	echo '<span class="subtitle">' . sprintf( __( 'Search results for &#8220;%s&#8221;' ), wp_html_excerpt( esc_html( wp_unslash( $_REQUEST['s'] ) ), 50, '&hellip;' ) ) . '</span>';
+}
+?>
+</div>
+<?php
 if ( isset( $_REQUEST['error'] ) ) {
 	$error = (int) $_REQUEST['error'];
 	$error_msg = '';
Index: src/wp-admin/edit-form-advanced.php
===================================================================
--- src/wp-admin/edit-form-advanced.php	(revision 33083)
+++ src/wp-admin/edit-form-advanced.php	(working copy)
@@ -414,11 +414,13 @@
 ?>
 
 <div class="wrap">
-<h1><?php
-echo esc_html( $title );
-if ( isset( $post_new_file ) && current_user_can( $post_type_object->cap->create_posts ) )
+<div class="header">
+<h1><?php echo esc_html( $title ); ?></h1>
+<?php if ( isset( $post_new_file ) && current_user_can( $post_type_object->cap->create_posts ) ) {
 	echo ' <a href="' . esc_url( admin_url( $post_new_file ) ) . '" class="page-title-action">' . esc_html( $post_type_object->labels->add_new ) . '</a>';
-?></h1>
+} ?>
+</div>
+
 <?php if ( $notice ) : ?>
 <div id="notice" class="notice notice-warning"><p id="has-newer-autosave"><?php echo $notice ?></p></div>
 <?php endif; ?>
Index: src/wp-admin/edit-link-form.php
===================================================================
--- src/wp-admin/edit-link-form.php	(revision 33083)
+++ src/wp-admin/edit-link-form.php	(working copy)
@@ -70,7 +70,10 @@
 ?>
 
 <div class="wrap">
-<h1><?php echo esc_html( $title ); ?>  <a href="link-add.php" class="page-title-action"><?php echo esc_html_x('Add New', 'link'); ?></a></h1>
+<div class="header">
+	<h1><?php echo esc_html( $title ); ?></h1>
+	<a href="link-add.php" class="page-title-action"><?php echo esc_html_x( 'Add New', 'link' ); ?></a>
+</div>
 
 <?php if ( isset( $_GET['added'] ) ) : ?>
 <div id="message" class="updated notice is-dismissible"><p><?php _e('Link added.'); ?></p></div>
Index: src/wp-admin/edit-tags.php
===================================================================
--- src/wp-admin/edit-tags.php	(revision 33083)
+++ src/wp-admin/edit-tags.php	(working copy)
@@ -312,10 +312,12 @@
 ?>
 
 <div class="wrap nosubsub">
-<h1><?php echo esc_html( $title );
-if ( !empty($_REQUEST['s']) )
-	printf( '<span class="subtitle">' . __('Search results for &#8220;%s&#8221;') . '</span>', esc_html( wp_unslash($_REQUEST['s']) ) ); ?>
-</h1>
+<div class="header">
+<h1><?php echo esc_html( $title ); ?></h1><?php
+if ( ! empty( $_REQUEST['s'] ) ) {
+	printf( '<span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', esc_html( wp_unslash( $_REQUEST['s'] ) ) );
+} ?>
+</div>
 
 <?php if ( $message ) : ?>
 <div id="message" class="<?php echo $class; ?> notice is-dismissible"><p><?php echo $message; ?></p></div>
Index: src/wp-admin/edit.php
===================================================================
--- src/wp-admin/edit.php	(revision 33083)
+++ src/wp-admin/edit.php	(working copy)
@@ -283,13 +283,17 @@
 require_once( ABSPATH . 'wp-admin/admin-header.php' );
 ?>
 <div class="wrap">
-<h1><?php
-echo esc_html( $post_type_object->labels->name );
-if ( current_user_can( $post_type_object->cap->create_posts ) )
+<div class="header">
+<h1><?php echo esc_html( $post_type_object->labels->name ); ?></h1>
+<?php
+if ( current_user_can( $post_type_object->cap->create_posts ) ) {
 	echo ' <a href="' . esc_url( admin_url( $post_new_file ) ) . '" class="page-title-action">' . esc_html( $post_type_object->labels->add_new ) . '</a>';
-if ( ! empty( $_REQUEST['s'] ) )
-	printf( ' <span class="subtitle">' . __('Search results for &#8220;%s&#8221;') . '</span>', get_search_query() );
-?></h1>
+}
+if ( ! empty( $_REQUEST['s'] ) ) {
+	printf( ' <span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', get_search_query() );
+}
+?>
+</div>
 
 <?php
 // If we have a bulk message to issue:
Index: src/wp-admin/js/theme.js
===================================================================
--- src/wp-admin/js/theme.js	(revision 33083)
+++ src/wp-admin/js/theme.js	(working copy)
@@ -84,7 +84,7 @@
 	},
 
 	// Defines search element container
-	searchContainer: $( '#wpbody h1:first' ),
+	searchContainer: $( '#wpbody .header:first' ),
 
 	// Search input and view
 	// for current theme collection
Index: src/wp-admin/link-manager.php
===================================================================
--- src/wp-admin/link-manager.php	(revision 33083)
+++ src/wp-admin/link-manager.php	(working copy)
@@ -69,10 +69,14 @@
 ?>
 
 <div class="wrap nosubsub">
-<h1><?php echo esc_html( $title ); ?> <a href="link-add.php" class="page-title-action"><?php echo esc_html_x('Add New', 'link'); ?></a> <?php
-if ( !empty($_REQUEST['s']) )
-	printf( '<span class="subtitle">' . __('Search results for &#8220;%s&#8221;') . '</span>', esc_html( wp_unslash($_REQUEST['s']) ) ); ?>
-</h1>
+<div class="header">
+<h1><?php echo esc_html( $title ); ?></h1>
+<a href="link-add.php" class="page-title-action"><?php echo esc_html_x( 'Add New', 'link' ); ?></a>
+<?php
+if ( ! empty( $_REQUEST['s'] ) ) {
+	printf( '<span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', esc_html( wp_unslash( $_REQUEST['s'] ) ) );
+} ?>
+</div>
 
 <?php
 if ( isset($_REQUEST['deleted']) ) {
Index: src/wp-admin/media.php
===================================================================
--- src/wp-admin/media.php	(revision 33083)
+++ src/wp-admin/media.php	(working copy)
@@ -103,13 +103,13 @@
 ?>
 
 <div class="wrap">
-<h1>
+<div class="header">
+<h1><?php echo esc_html( $title ); ?></h1>
 <?php
-echo esc_html( $title );
 if ( current_user_can( 'upload_files' ) ) { ?>
-	<a href="media-new.php" class="page-title-action"><?php echo esc_html_x('Add New', 'file'); ?></a>
+	<a href="media-new.php" class="page-title-action"><?php echo esc_html_x( 'Add New', 'file' ); ?></a>
 <?php } ?>
-</h1>
+</div>
 
 <form method="post" class="media-upload-form" id="media-single-form">
 <p class="submit" style="padding-bottom: 0;">
Index: src/wp-admin/nav-menus.php
===================================================================
--- src/wp-admin/nav-menus.php	(revision 33083)
+++ src/wp-admin/nav-menus.php	(working copy)
@@ -558,6 +558,7 @@
 require_once( ABSPATH . 'wp-admin/admin-header.php' );
 ?>
 <div class="wrap">
+	<div class="header">
 	<h1 class="nav-tab-wrapper">
 		<a href="<?php echo admin_url( 'nav-menus.php' ); ?>" class="nav-tab<?php if ( ! isset( $_GET['action'] ) || isset( $_GET['action'] ) && 'locations' != $_GET['action'] ) echo ' nav-tab-active'; ?>"><?php esc_html_e( 'Edit Menus' ); ?></a>
 		<?php if ( $num_locations && $menu_count ) : ?>
@@ -579,6 +580,7 @@
 			}
 		?>
 	</h1>
+	</div>
 	<?php
 	foreach( $messages as $message ) :
 		echo $message . "\n";
Index: src/wp-admin/network/sites.php
===================================================================
--- src/wp-admin/network/sites.php	(revision 33083)
+++ src/wp-admin/network/sites.php	(working copy)
@@ -248,7 +248,8 @@
 ?>
 
 <div class="wrap">
-<h1><?php _e( 'Sites' ); ?>
+<div class="header">
+<h1><?php _e( 'Sites' ); ?></h1>
 
 <?php if ( current_user_can( 'create_sites') ) : ?>
 	<a href="<?php echo network_admin_url('site-new.php'); ?>" class="page-title-action"><?php echo esc_html_x( 'Add New', 'site' ); ?></a>
@@ -257,7 +258,7 @@
 <?php if ( isset( $_REQUEST['s'] ) && $_REQUEST['s'] ) {
 	printf( '<span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', esc_html( $s ) );
 } ?>
-</h1>
+</div>
 
 <?php echo $msg; ?>
 
Index: src/wp-admin/network/themes.php
===================================================================
--- src/wp-admin/network/themes.php	(revision 33083)
+++ src/wp-admin/network/themes.php	(working copy)
@@ -261,11 +261,19 @@
 ?>
 
 <div class="wrap">
-<h1><?php echo esc_html( $title ); if ( current_user_can('install_themes') ) { ?> <a href="theme-install.php" class="page-title-action"><?php echo esc_html_x('Add New', 'theme'); ?></a><?php }
-if ( $s )
-	printf( '<span class="subtitle">' . __('Search results for &#8220;%s&#8221;') . '</span>', esc_html( $s ) ); ?>
-</h1>
+<div class="header">
+<h1><?php echo esc_html( $title ); ?></h1>
+<?php
+if ( current_user_can( 'install_themes' ) ) : ?>
+	<a href="theme-install.php" class="page-title-action"><?php echo esc_html_x( 'Add New', 'theme' ); ?></a><?php
+endif;
 
+if ( $s ) {
+	printf( '<span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', esc_html( $s ) );
+}
+?>
+</div>
+
 <?php
 if ( isset( $_GET['enabled'] ) ) {
 	$enabled = absint( $_GET['enabled'] );
Index: src/wp-admin/network/users.php
===================================================================
--- src/wp-admin/network/users.php	(revision 33083)
+++ src/wp-admin/network/users.php	(working copy)
@@ -309,15 +309,18 @@
 }
 	?>
 <div class="wrap">
-	<h1><?php esc_html_e( 'Users' );
+	<div class="header">
+	<h1><?php esc_html_e( 'Users' ); ?></h1>
+	<?php
 	if ( current_user_can( 'create_users') ) : ?>
-		<a href="<?php echo network_admin_url('user-new.php'); ?>" class="page-title-action"><?php echo esc_html_x( 'Add New', 'user' ); ?></a><?php
+		<a href="<?php echo network_admin_url( 'user-new.php' ); ?>" class="page-title-action"><?php echo esc_html_x( 'Add New', 'user' ); ?></a><?php
 	endif;
 
-	if ( !empty( $usersearch ) )
-	printf( '<span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', esc_html( $usersearch ) );
+	if ( ! empty( $usersearch ) ) {
+		printf( '<span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', esc_html( $usersearch ) );
+	}
 	?>
-	</h1>
+	</div>
 
 	<?php $wp_list_table->views(); ?>
 
Index: src/wp-admin/plugin-install.php
===================================================================
--- src/wp-admin/plugin-install.php	(revision 33083)
+++ src/wp-admin/plugin-install.php	(working copy)
@@ -94,9 +94,9 @@
 include(ABSPATH . 'wp-admin/admin-header.php');
 ?>
 <div class="wrap">
-<h1>
+<div class="header">
+	<h1><?php echo esc_html( $title ); ?></h1>
 	<?php
-	echo esc_html( $title );
 	if ( ! empty( $tabs['upload'] ) && current_user_can( 'upload_plugins' ) ) {
 		if ( $tab === 'upload' ) {
 			$href = self_admin_url( 'plugin-install.php' );
@@ -108,7 +108,7 @@
 		echo ' <a href="' . $href . '" class="upload page-title-action">' . $text . '</a>';
 	}
 	?>
-</h1>
+</div>
 
 <?php
 if ( $tab !== 'upload' ) {
Index: src/wp-admin/plugins.php
===================================================================
--- src/wp-admin/plugins.php	(revision 33083)
+++ src/wp-admin/plugins.php	(working copy)
@@ -446,13 +446,17 @@
 <?php endif; ?>
 
 <div class="wrap">
-<h1><?php echo esc_html( $title );
-if ( ( ! is_multisite() || is_network_admin() ) && current_user_can('install_plugins') ) { ?>
- <a href="<?php echo self_admin_url( 'plugin-install.php' ); ?>" class="page-title-action"><?php echo esc_html_x('Add New', 'plugin'); ?></a>
+<div class="header">
+<h1><?php echo esc_html( $title ); ?></h1>
+<?php
+if ( ( ! is_multisite() || is_network_admin() ) && current_user_can( 'install_plugins' ) ) { ?>
+	<a href="<?php echo self_admin_url( 'plugin-install.php' ); ?>" class="page-title-action"><?php echo esc_html_x( 'Add New', 'plugin' ); ?></a>
 <?php }
-if ( $s )
-	printf( '<span class="subtitle">' . __('Search results for &#8220;%s&#8221;') . '</span>', esc_html( $s ) ); ?>
-</h1>
+if ( $s ) {
+	printf( '<span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', esc_html( $s ) );
+}
+ ?>
+</div>
 
 <?php
 /**
Index: src/wp-admin/theme-install.php
===================================================================
--- src/wp-admin/theme-install.php	(revision 33083)
+++ src/wp-admin/theme-install.php	(working copy)
@@ -102,9 +102,9 @@
 
 ?>
 <div class="wrap">
-	<h1><?php
-	echo esc_html( $title );
-
+	<div class="header">
+	<h1><?php echo esc_html( $title ); ?></h1>
+	<?php
 	/**
 	 * Filter the tabs shown on the Add Themes screen.
 	 *
@@ -120,7 +120,8 @@
 		echo ' <a href="#" class="upload page-title-action">' . __( 'Upload Theme' ) . '</a>';
 		echo ' <a href="#" class="browse-themes page-title-action">' . _x( 'Browse', 'themes' ) . '</a>';
 	}
-	?></h1>
+	?>
+	</div>
 
 	<div class="upload-theme">
 	<?php install_themes_upload(); ?>
Index: src/wp-admin/themes.php
===================================================================
--- src/wp-admin/themes.php	(revision 33083)
+++ src/wp-admin/themes.php	(working copy)
@@ -124,12 +124,12 @@
 ?>
 
 <div class="wrap">
-	<h1><?php esc_html_e( 'Themes' ); ?>
+<div class="header">
+	<h1><?php esc_html_e( 'Themes' ); ?></h1>
 		<span class="title-count theme-count"><?php echo count( $themes ); ?></span>
 	<?php if ( ! is_multisite() && current_user_can( 'install_themes' ) ) : ?>
 		<a href="<?php echo admin_url( 'theme-install.php' ); ?>" class="hide-if-no-js page-title-action"><?php echo esc_html_x( 'Add New', 'Add new theme' ); ?></a>
 	<?php endif; ?>
-	</h1>
 <?php
 if ( ! validate_current_theme() || isset( $_GET['broken'] ) ) : ?>
 <div id="message1" class="updated notice is-dismissible"><p><?php _e('The active theme is broken. Reverting to the default theme.'); ?></p></div>
@@ -200,7 +200,7 @@
 	}
 
 ?>
-
+</div>
 <div class="theme-browser">
 	<div class="themes">
 
Index: src/wp-admin/upload.php
===================================================================
--- src/wp-admin/upload.php	(revision 33083)
+++ src/wp-admin/upload.php	(working copy)
@@ -71,14 +71,14 @@
 	require_once( ABSPATH . 'wp-admin/admin-header.php' );
 	?>
 	<div class="wrap" id="wp-media-grid" data-search="<?php _admin_search_query() ?>">
-		<h1>
+		<div class="header">
+		<h1><?php echo esc_html( $title ); ?></h1>
 		<?php
-		echo esc_html( $title );
 		if ( current_user_can( 'upload_files' ) ) { ?>
 			<a href="media-new.php" class="page-title-action"><?php echo esc_html_x( 'Add New', 'file' ); ?></a><?php
 		}
 		?>
-		</h1>
+		</div>
 		<div class="error hide-if-js">
 			<p><?php _e( 'The grid view for the Media Library requires JavaScript. <a href="upload.php?mode=list">Switch to the list view</a>.' ); ?></p>
 		</div>
@@ -206,15 +206,16 @@
 ?>
 
 <div class="wrap">
-<h1>
+<div class="header">
+<h1><?php echo esc_html( $title ); ?></h1>
 <?php
-echo esc_html( $title );
 if ( current_user_can( 'upload_files' ) ) { ?>
-	<a href="media-new.php" class="page-title-action"><?php echo esc_html_x('Add New', 'file'); ?></a><?php
+	<a href="media-new.php" class="page-title-action"><?php echo esc_html_x( 'Add New', 'file' ); ?></a><?php
 }
-if ( ! empty( $_REQUEST['s'] ) )
-	printf( '<span class="subtitle">' . __('Search results for &#8220;%s&#8221;') . '</span>', get_search_query() ); ?>
-</h1>
+if ( ! empty( $_REQUEST['s'] ) ) {
+	printf( '<span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', get_search_query() );
+} ?>
+</div>
 
 <?php
 $message = '';
Index: src/wp-admin/user-edit.php
===================================================================
--- src/wp-admin/user-edit.php	(revision 33083)
+++ src/wp-admin/user-edit.php	(working copy)
@@ -202,9 +202,9 @@
 <?php endif; ?>
 
 <div class="wrap" id="profile-page">
-<h1>
+<div class="header">
+<h1><?php echo esc_html( $title ); ?></h1>
 <?php
-echo esc_html( $title );
 if ( ! IS_PROFILE_PAGE ) {
 	if ( current_user_can( 'create_users' ) ) { ?>
 		<a href="user-new.php" class="page-title-action"><?php echo esc_html_x( 'Add New', 'user' ); ?></a>
@@ -212,7 +212,7 @@
 		<a href="user-new.php" class="page-title-action"><?php echo esc_html_x( 'Add Existing', 'user' ); ?></a>
 	<?php }
 } ?>
-</h1>
+</div>
 <form id="your-profile" action="<?php echo esc_url( self_admin_url( IS_PROFILE_PAGE ? 'profile.php' : 'user-edit.php' ) ); ?>" method="post" novalidate="novalidate"<?php
 	/**
 	 * Fires inside the your-profile form tag on the user editing screen.
Index: src/wp-admin/users.php
===================================================================
--- src/wp-admin/users.php	(revision 33083)
+++ src/wp-admin/users.php	(working copy)
@@ -443,19 +443,20 @@
 } ?>
 
 <div class="wrap">
-<h1>
+<div class="header">
+<h1><?php echo esc_html( $title );?></h1>
 <?php
-echo esc_html( $title );
 if ( current_user_can( 'create_users' ) ) { ?>
 	<a href="user-new.php" class="page-title-action"><?php echo esc_html_x( 'Add New', 'user' ); ?></a>
 <?php } elseif ( is_multisite() && current_user_can( 'promote_users' ) ) { ?>
 	<a href="user-new.php" class="page-title-action"><?php echo esc_html_x( 'Add Existing', 'user' ); ?></a>
 <?php }
+if ( $usersearch ) {
+	printf( '<span class="subtitle">' . __( 'Search results for &#8220;%s&#8221;' ) . '</span>', esc_html( $usersearch ) );
+}
+?>
+</div>
 
-if ( $usersearch )
-	printf( '<span class="subtitle">' . __('Search results for &#8220;%s&#8221;') . '</span>', esc_html( $usersearch ) ); ?>
-</h1>
-
 <?php $wp_list_table->views(); ?>
 
 <form method="get">
Index: src/wp-admin/widgets.php
===================================================================
--- src/wp-admin/widgets.php	(revision 33083)
+++ src/wp-admin/widgets.php	(working copy)
@@ -315,9 +315,9 @@
 require_once( ABSPATH . 'wp-admin/admin-header.php' ); ?>
 
 <div class="wrap">
-<h1>
+<div class="header">
+<h1><?php echo esc_html( $title ); ?></h1>
 <?php
-	echo esc_html( $title );
 	if ( current_user_can( 'customize' ) ) {
 		printf(
 			' <a class="page-title-action hide-if-no-customize" href="%1$s">%2$s</a>',
@@ -332,7 +332,7 @@
 		);
 	}
 ?>
-</h1>
+</div>
 
 <?php if ( isset($_GET['message']) && isset($messages[$_GET['message']]) ) { ?>
 <div id="message" class="updated notice is-dismissible"><p><?php echo $messages[$_GET['message']]; ?></p></div>

Index: src/wp-admin/js/common.js
===================================================================
--- src/wp-admin/js/common.js	(revision 33083)
+++ src/wp-admin/js/common.js	(working copy)
@@ -370,9 +370,9 @@
 	}
 
 	// Move .notice, .updated and .error alert boxes. Don't move boxes designed to be inline.
-	$firstHeading = $( '.wrap > h1:first' );
+	$firstHeading = $( '.wrap > h1:first, .wrap > .header:first' );
 
 	// Back compatibility: if there is no H1, apply to first H2.
 	if ( ! $firstHeading.length ) {
 		$firstHeading = $( '.wrap h2:first' );
 	}
@@ -370,9 +370,9 @@
 
-	// Back compatibility: if there is no H1, apply to first H2.
+	// Back compatibility: if there is no H1 or div.header, apply to first H2.
 	if ( ! $firstHeading.length ) {
 		$firstHeading = $( '.wrap h2:first' );